API
===

.. automodule:: academic_tracker

.. automodule:: academic_tracker.user_input_checking
    :members:

.. automodule:: academic_tracker.athr_srch_modularized
    :members:
.. automodule:: academic_tracker.athr_srch_webio
    :members:
.. automodule:: academic_tracker.athr_srch_emails_and_reports
    :members:

.. automodule:: academic_tracker.ref_srch_modularized
    :members:
.. automodule:: academic_tracker.ref_srch_webio
    :members:
.. automodule:: academic_tracker.ref_srch_emails_and_reports
    :members:
.. automodule:: academic_tracker.citation_parsing
    :members:

.. automodule:: academic_tracker.fileio
    :members:
.. automodule:: academic_tracker.helper_functions
    :members:
.. automodule:: academic_tracker.webio
    :members:


